==> haskell-hs-bibutils-6.7.0.0-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hs-bibutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hs-bibutils
version: 6.7.0.0
id: hs-bibutils-6.7.0.0-7IxUCH6XuWX79SdlBxgzqa
key: hs-bibutils-6.7.0.0-7IxUCH6XuWX79SdlBxgzqa
license: LicenseRef-GPL
maintainer: Václav Haisman <vhaisman@gmail.com>
author: Andrea Rossato
homepage: https://github.com/wilx/hs-bibutils
synopsis: Haskell bindings to bibutils, the bibliography
          conversion utilities.
description:
    Haskell bindings to Chris Putnam'\''s bibutils, a
    library that interconverts between various
    bibliography formats using a common MODS-format
    XML intermediate.
    .
    hs-bibutils is available under the GNU GPL license. See
    the LICENSE file for details.
    .
    For more details about bibutils, please check:
    <http://sourceforge.net/p/bibutils/home/Bibutils/>.
    .
    The package release number refers to the release number of
    the included bibutils library.
category: Text
abi: 8e71ade9aca74e02e9edc0ed85d441da
exposed: True
exposed-modules:
    Text.Bibutils
import-dirs: /usr/lib/ghc-8.6.5/site-local/hs-bibutils-6.7.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hs-bibutils-6.7.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hs-bibutils-6.7.0.0
hs-libraries: HShs-bibutils-6.7.0.0-7IxUCH6XuWX79SdlBxgzqa
includes:
    bibutils.h
depends:
    base-4.12.0.0 syb-0.7-KRW1LCxdMiCJrmhxCvzo37
haddock-interfaces: /usr/share/doc/haskell-hs-bibutils/html/hs-bibutils.haddock
haddock-html: /usr/share/doc/haskell-hs-bibutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hs-bibutils-6.7.0.0-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hs-bibutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hs-bibutils
version: 6.7.0.0
id: hs-bibutils-6.7.0.0-FZxrSZg5Y3h1rDYhDXLOxx
key: hs-bibutils-6.7.0.0-FZxrSZg5Y3h1rDYhDXLOxx
license: LicenseRef-GPL
maintainer: Václav Haisman <vhaisman@gmail.com>
author: Andrea Rossato
homepage: https://github.com/wilx/hs-bibutils
synopsis: Haskell bindings to bibutils, the bibliography
          conversion utilities.
description:
    Haskell bindings to Chris Putnam'\''s bibutils, a
    library that interconverts between various
    bibliography formats using a common MODS-format
    XML intermediate.
    .
    hs-bibutils is available under the GNU GPL license. See
    the LICENSE file for details.
    .
    For more details about bibutils, please check:
    <http://sourceforge.net/p/bibutils/home/Bibutils/>.
    .
    The package release number refers to the release number of
    the included bibutils library.
category: Text
abi: 1aca971d3c900b6bed07d52e38d11910
exposed: True
exposed-modules:
    Text.Bibutils
import-dirs: /usr/lib/ghc-8.6.5/site-local/hs-bibutils-6.7.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hs-bibutils-6.7.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hs-bibutils-6.7.0.0
hs-libraries: HShs-bibutils-6.7.0.0-FZxrSZg5Y3h1rDYhDXLOxx
includes:
    bibutils.h
depends:
    base-4.12.0.0 syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
haddock-interfaces: /usr/share/doc/haskell-hs-bibutils/html/hs-bibutils.haddock
haddock-html: /usr/share/doc/haskell-hs-bibutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
